@@ -19,6 +19,7 @@ class VirtualMachineInstance(NamespacedResource):
 
     class Status(NamespacedResource.Status):
         SCHEDULING = "Scheduling"
+        SCHEDULED = "Scheduled"
 
     def __init__(
         self,
@@ -74,6 +75,9 @@ class VirtualMachineInstance(NamespacedResource):
                 label_selector=f"kubevirt.io=virt-launcher,kubevirt.io/created-by={self.instance.metadata.uid}",
             )
         )
+        if not pods:
+            raise ResourceNotFoundError(f"VIRT launcher POD not found for {self.kind}:{self.name}")
+
         migration_state = self.instance.status.migrationState
         if migration_state:
             #  After VM migration there are two pods, one in Completed status and one in Running status.
@@ -84,8 +88,6 @@ class VirtualMachineInstance(NamespacedResource):
         else:
             return pods[0]
 
-        raise ResourceNotFoundError(f"VIRT launcher POD not found for {self.kind}:{self.name}")
-
     @property
     def virt_handler_pod(self):
         pods = list(
@@ -193,7 +195,7 @@ class VirtualMachineInstance(NamespacedResource):
 
     def virsh_cmd(self, action):
         return shlex.split(
-            f"virsh {self.virt_launcher_pod_hypervisor_connection_uri} {action} {self.namespace}_{self.name}"
+            "virsh" f" {self.virt_launcher_pod_hypervisor_connection_uri} {action} {self.namespace}_{self.name}"
         )
 
     def get_xml(self):
